@@ -9,7 +9,8 @@ from .text import Text
 
 class Date(Text):
 
-    """A date field formatted as yyy-MM-dd
+    """A date field formatted as yyy-MM-dd. Example: 1980-07-28
+    This field DOES NOT make any timezone conversions
 
     :param validate:
         An list of validators. This will evaluate the current `value` when
