@@ -1,6 +1,6 @@
 from .validator import Validator
 from .simple import Required, IsNumber
-from .dates import IsDate, Before, After, BeforeNow, AfterNow
+from .dates import IsDate, IsTime, Before, After, BeforeNow, AfterNow
 from .values import LongerThan, ShorterThan, LessThan, MoreThan, InRange
 from .patterns import Match, ValidEmail, ValidURL, IsColor
 
